copy audio\*.vgz temp\*.gz
for %%a in (temp\*.gz) do gzip.exe -d "%%a"
copy temp\*.* audio\*.vgm
del  /f /q temp\*.*
for %%I in (audio\*.vgm) do ffmpeg.exe -y -i "%%I" -f wav -t 180 "audio\%%~nI.wav
del /f /q audio\*.vgz
del /f /q audio\*.vgm
pause