@echo off
for %%I in (audio\*.adx) do ffmpeg.exe -y -i "%%I" "audio\%%~nI.wav
for %%I in (audio\*.xm) do ffmpeg.exe -y -i "%%I" "audio\%%~nI.wav
for %%I in (audio\*.mod) do ffmpeg.exe -y -i "%%I" "audio\%%~nI.wav
for %%I in (audio\*.it) do ffmpeg.exe -y -i "%%I" "audio\%%~nI.wav
for %%I in (audio\*.flac) do ffmpeg.exe -y -i "%%I" "audio\%%~nI.wav
for %%I in (audio\*.ogg) do ffmpeg.exe -y -i "%%I" "audio\%%~nI.wav
for %%I in (audio\*.mp3) do ffmpeg.exe -y -i "%%I" "audio\%%~nI.wav
for %%I in (audio\*.aac) do ffmpeg.exe -y -i "%%I" -f wav "audio\%%~nI.wav
for %%I in (audio\*.wma) do ffmpeg.exe -y -i "%%I" -f wav "audio\%%~nI.wav
for %%I in (audio\*.avi) do ffmpeg.exe -y -i "%%I" -f wav "audio\%%~nI.wav
for %%I in (audio\*.flv) do ffmpeg.exe -y -i "%%I" -f wav "audio\%%~nI.wav
for %%I in (audio\*.mpg) do ffmpeg.exe -y -i "%%I" -f wav "audio\%%~nI.wav
for %%I in (audio\*.mp4) do ffmpeg.exe -y -i "%%I" -f wav "audio\%%~nI.wav
for %%I in (audio\*.s3m) do ffmpeg.exe -y -i "%%I" -f wav "audio\%%~nI.wav
for %%I in (audio\*.wma) do ffmpeg.exe -y -i "%%I" -f wav "audio\%%~nI.wav
for %%I in (audio\*.spc) do ffmpeg.exe -y -i "%%I" -f wav -t 180 "audio\%%~nI.wav
for %%I in (audio\*.vgm) do ffmpeg.exe -y -i "%%I" -f wav -t 180 "audio\%%~nI.wav


@REM decompress VGZ to VGM and covert it to wav via ffmpeg
IF NOT EXIST audio\*.vgz GOTO SKIP2
copy audio\*.vgz temp\*.gz
for %%a in (temp\*.gz) do gzip.exe -d "%%a"
copy temp\*.* audio\*.vgm
del  /f /q temp\*.*
for %%I in (audio\*.vgm) do ffmpeg.exe -y -i "%%I" -f wav -t 180 "audio\%%~nI.wav
del /f /q audio\*.vgz
del /f /q audio\*.vgm
:SKIP2
@REM End section


@REM ресемплер от CRI. Изменяет параметры WAV под CDDA. Если исходный файл и так стерео, 16бит 44100Кг, то не стоит им пользоваться. Он здесь только для того, чтобы переделать низкокачественные файлы разных форматов в дримочитаемый.
@REM все файлы копируются во временную папку и WAV обрабатываются ресемплером и возвращаются
IF NOT EXIST audio\*.wav GOTO SKIP03
for %%I in (audio\*.*) do move  "%%I" "temp\" 
for %%I in (temp\*.wav) do wavrsmp.exe "%%I" -out "audio\%%~nI.wav" -ch=2 -freq=44100 -bit=16 -mode=speed



@REM тут их ждет ковертер в RAW
for %%I in (audio\*.wav) do sox.exe "%%I" "audio\%%~nI.raw

@REM очищаем временные файлы, сначала убирая аттрибуты
for %%I in (temp\*.*) do attrib "%%I" -r -h -s -a /s
del /Q /F temp\*.*
del /Q /F audio\*.wav
:SKIP03
del /Q /F temp\*.*



:END
ECHO Done! Superb!